import _extends from "@babel/runtime/helpers/extends";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import React, { useState, useEffect, useRef } from 'react';
import PropTypes from 'prop-types';
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import CarbonTimePicker from "carbon-components-react/es/components/TimePicker/TimePicker.js";
import TimePickerSelect from "carbon-components-react/es/components/TimePickerSelect/TimePickerSelect.js";
import SelectItem from "carbon-components-react/es/components/SelectItem/SelectItem.js";
import prepareProps from '../prepare-props';
import HelperTextBlock from '../helper-text-block/helper-text-block';

var TimePicker = function TimePicker(props) {
  var _timezones$;

  var _useFieldApi = useFieldApi(prepareProps(props)),
      input = _useFieldApi.input,
      meta = _useFieldApi.meta,
      twelveHoursFormat = _useFieldApi.twelveHoursFormat,
      timezones = _useFieldApi.timezones,
      validateOnMount = _useFieldApi.validateOnMount,
      helperText = _useFieldApi.helperText,
      WrapperProps = _useFieldApi.WrapperProps,
      rest = _objectWithoutProperties(_useFieldApi, ["input", "meta", "twelveHoursFormat", "timezones", "validateOnMount", "helperText", "WrapperProps"]);

  var _useState = useState(timezones ? (_timezones$ = timezones[0]) === null || _timezones$ === void 0 ? void 0 : _timezones$.value : ''),
      _useState2 = _slicedToArray(_useState, 2),
      timezone = _useState2[0],
      selectTimezone = _useState2[1];

  var _useState3 = useState('AM'),
      _useState4 = _slicedToArray(_useState3, 2),
      format = _useState4[0],
      selectFormat = _useState4[1];

  var isMounted = useRef(false);
  var invalid = (meta.touched || validateOnMount) && (meta.error || meta.submitError);
  var warnText = (meta.touched || validateOnMount) && meta.warning;
  var finalValue = input.value;

  if (input.value instanceof Date) {
    var _timezones$find;

    var _input$value$toLocale = input.value.toLocaleTimeString('en-us', {
      hour12: !!twelveHoursFormat,
      timeZone: timezones === null || timezones === void 0 ? void 0 : (_timezones$find = timezones.find(function (_ref) {
        var value = _ref.value;
        return value === timezone;
      })) === null || _timezones$find === void 0 ? void 0 : _timezones$find.showAs
    }).split(':'),
        _input$value$toLocale2 = _slicedToArray(_input$value$toLocale, 2),
        _input$value$toLocale3 = _input$value$toLocale2[0],
        hours = _input$value$toLocale3 === void 0 ? '00' : _input$value$toLocale3,
        _input$value$toLocale4 = _input$value$toLocale2[1],
        minutes = _input$value$toLocale4 === void 0 ? '00' : _input$value$toLocale4;

    finalValue = "".concat(String(hours).padStart(2, '0'), ":").concat(String(minutes).padStart(2, '0'));
  }

  var enhnancedOnBlur = function enhnancedOnBlur() {
    var _finalValue;

    var _ref2 = ((_finalValue = finalValue) === null || _finalValue === void 0 ? void 0 : _finalValue.split(':')) || [],
        _ref3 = _slicedToArray(_ref2, 2),
        _ref3$ = _ref3[0],
        hours = _ref3$ === void 0 ? '00' : _ref3$,
        _ref3$2 = _ref3[1],
        minutes = _ref3$2 === void 0 ? '00' : _ref3$2;

    if (!hours || isNaN(hours)) {
      hours = '00';
    }

    if (!minutes || isNaN(minutes)) {
      minutes = '00';
    }

    if (twelveHoursFormat) {
      hours = hours % 12;

      if (format === 'PM') {
        hours = hours + 12;
      }
    } else {
      hours = hours % 24;
    }

    minutes = minutes % 59;
    var enhancedValue = new Date("Jan 1 2000 ".concat(hours, ":").concat(minutes, ":00 ").concat(timezone));
    input.onChange(enhancedValue);
    input.onBlur();
  };

  useEffect(function () {
    if (isMounted.current === true) {
      enhnancedOnBlur();
    } else {
      isMounted.current = true;
    }
  }, [timezone, format]);
  return /*#__PURE__*/React.createElement("div", WrapperProps, /*#__PURE__*/React.createElement(CarbonTimePicker, _extends({}, input, {
    value: finalValue,
    onBlur: enhnancedOnBlur,
    key: input.name,
    id: input.name,
    invalid: Boolean(invalid),
    invalidText: invalid || ''
  }, rest), twelveHoursFormat && /*#__PURE__*/React.createElement(TimePickerSelect, {
    labelText: "Period",
    id: "".concat(rest.id || input.name, "-12h"),
    onChange: function onChange(_ref4) {
      var value = _ref4.target.value;
      return selectFormat(value);
    }
  }, /*#__PURE__*/React.createElement(SelectItem, {
    value: "AM",
    text: "AM"
  }), /*#__PURE__*/React.createElement(SelectItem, {
    value: "PM",
    text: "PM"
  })), timezones && /*#__PURE__*/React.createElement(TimePickerSelect, {
    labelText: "Timezone",
    id: "".concat(rest.id || input.name, "-timezones"),
    onChange: function onChange(_ref5) {
      var value = _ref5.target.value;
      return selectTimezone(value);
    }
  }, timezones.map(function (_ref6) {
    var showAs = _ref6.showAs,
        tz = _objectWithoutProperties(_ref6, ["showAs"]);

    return /*#__PURE__*/React.createElement(SelectItem, _extends({
      key: tz.value,
      text: tz.label
    }, tz));
  }))), /*#__PURE__*/React.createElement(HelperTextBlock, {
    helperText: !invalid && helperText,
    warnText: warnText
  }));
};

TimePicker.propTypes = {
  isDisabled: PropTypes.bool,
  isReadOnly: PropTypes.bool,
  isRequired: PropTypes.bool,
  label: PropTypes.node,
  labelText: PropTypes.node,
  description: PropTypes.node,
  twelveHoursFormat: PropTypes.bool,
  timezones: PropTypes.arrayOf(PropTypes.shape({
    value: PropTypes.string.isRequired,
    label: PropTypes.node.isRequired,
    showAs: PropTypes.string.isRequired
  })),
  WrapperProps: PropTypes.object
};
export default TimePicker;